@@ -15,7 +15,7 @@ function (u, beta = NULL, distname = c("normal"))
         FU = function(u) pnorm(u)
     }
     if (distname == "t") {
-	ss = beta2theta(beta, distname=distname)[2]
+	ss = beta2tau(beta, distname=distname)[2]
         FU = function(u) pt(u*ss, df = beta[3])
     }
     if (distname == "unif") {
